@@ -2,7 +2,7 @@ package elasticsearchunmanaged
 
 import (
 	"fmt"
-	"github.com/openshift/cluster-logging-operator/pkg/constants"
+	"github.com/openshift/cluster-logging-operator/internal/constants"
 	framework "github.com/openshift/cluster-logging-operator/test/framework/e2e"
 	"path/filepath"
 	"runtime"
@@ -13,9 +13,9 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	"github.com/ViaQ/logerr/log"
-	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
+	logging "github.com/openshift/cluster-logging-operator/apis/logging/v1"
 	"github.com/openshift/cluster-logging-operator/test/helpers"
-	elasticsearch "github.com/openshift/elasticsearch-operator/pkg/apis/logging/v1"
+	elasticsearch "github.com/openshift/elasticsearch-operator/apis/logging/v1"
 )
 
 var _ = Describe("[ClusterLogForwarder] Forwards logs", func() {
@@ -50,7 +50,7 @@ var _ = Describe("[ClusterLogForwarder] Forwards logs", func() {
 			forwarder := &logging.ClusterLogForwarder{
 				TypeMeta: metav1.TypeMeta{
 					Kind:       logging.ClusterLogForwarderKind,
-					APIVersion: logging.SchemeGroupVersion.String(),
+					APIVersion: logging.GroupVersion.String(),
 				},
 				ObjectMeta: metav1.ObjectMeta{
 					Name: "instance",
@@ -99,7 +99,7 @@ var _ = Describe("[ClusterLogForwarder] Forwards logs", func() {
 
 		AfterEach(func() {
 			e2e.Cleanup()
-			e2e.WaitForCleanupCompletion(constants.OpenshiftNS, []string{"fluentd", "elasticsearch"})
+			e2e.WaitForCleanupCompletion(constants.OpenshiftNS, []string{constants.CollectorName, "elasticsearch"})
 		})
 
 		It("should send logs to the forward.Output logstore", func() {
