@@ -4,7 +4,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"github.com/openshift/cluster-logging-operator/pkg/constants"
+	"github.com/openshift/cluster-logging-operator/internal/constants"
 	"github.com/openshift/cluster-logging-operator/test/helpers"
 	"math/rand"
 	"os"
@@ -27,11 +27,11 @@ import (
 	"k8s.io/client-go/rest"
 
 	clolog "github.com/ViaQ/logerr/log"
-	cl "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	"github.com/openshift/cluster-logging-operator/pkg/certificates"
-	k8shandler "github.com/openshift/cluster-logging-operator/pkg/k8shandler"
-	"github.com/openshift/cluster-logging-operator/pkg/utils"
+	cl "github.com/openshift/cluster-logging-operator/apis/logging/v1"
+	logging "github.com/openshift/cluster-logging-operator/apis/logging/v1"
+	"github.com/openshift/cluster-logging-operator/internal/certificates"
+	k8shandler "github.com/openshift/cluster-logging-operator/internal/k8shandler"
+	"github.com/openshift/cluster-logging-operator/internal/utils"
 	"github.com/openshift/cluster-logging-operator/test/helpers/oc"
 )
 
@@ -223,7 +223,7 @@ func (tc *E2ETestFramework) waitForFluentDaemonSet(retryInterval, timeout time.D
 	maxtimes := 5
 	times := 0
 	return wait.PollImmediate(retryInterval, timeout, func() (bool, error) {
-		numUnavail, err := oc.Literal().From("oc -n openshift-logging get daemonset/fluentd -o jsonpath={.status.NumberUnavailable}").Run()
+		numUnavail, err := oc.Literal().From("oc -n openshift-logging get daemonset/collector -o jsonpath={.status.NumberUnavailable}").Run()
 		if err == nil {
 			if numUnavail == "" {
 				numUnavail = "0"
@@ -298,7 +298,7 @@ func (tc *E2ETestFramework) waitForDeployment(namespace, name string, retryInter
 			return false, nil
 		}
 		replicas := int(*deployment.Spec.Replicas)
-		if int(deployment.Status.ReadyReplicas) == replicas {
+		if int(deployment.Status.AvailableReplicas) == replicas {
 			return true, nil
 		}
 		return false, nil
@@ -411,8 +411,8 @@ func (tc *E2ETestFramework) CreateClusterLogForwarder(forwarder *logging.Cluster
 func (tc *E2ETestFramework) Cleanup() {
 	if g, ok := test.GinkgoCurrentTest(); ok && g.Failed {
 		//allow caller to cleanup if unset (e.g script cleanup())
-		clolog.Info("Running Cleanup script ....")
 		doCleanup := strings.TrimSpace(os.Getenv("DO_CLEANUP"))
+		clolog.Info("Running Cleanup script ....", "DO_CLEANUP", "doCleanup")
 		if doCleanup == "" || strings.ToLower(doCleanup) == "true" {
 			RunCleanupScript()
 		}
@@ -435,6 +435,7 @@ func RunCleanupScript() {
 			clolog.Info("No cleanup script provided")
 			return
 		}
+		clolog.Info("Script", "CLEANUP_CMD", value)
 		args := strings.Split(value, " ")
 		// #nosec G204
 		cmd := exec.Command(args[0], args[1:]...)
@@ -454,19 +455,19 @@ func (tc *E2ETestFramework) CleanFluentDBuffers() {
 			APIVersion: "apps/v1",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:      "clean-fluentd-buffers",
+			Name:      "clean-buffers",
 			Namespace: "default",
 		},
 		Spec: v1.DaemonSetSpec{
 			Selector: &metav1.LabelSelector{
 				MatchLabels: map[string]string{
-					"name": "clean-fluentd-buffers",
+					"name": "clean-buffers",
 				},
 			},
 			Template: corev1.PodTemplateSpec{
 				ObjectMeta: metav1.ObjectMeta{
 					Labels: map[string]string{
-						"name": "clean-fluentd-buffers",
+						"name": "clean-buffers",
 					},
 				},
 				Spec: corev1.PodSpec{
@@ -478,7 +479,7 @@ func (tc *E2ETestFramework) CleanFluentDBuffers() {
 					},
 					InitContainers: []corev1.Container{
 						{
-							Name:  "clean-fluentd-buffers",
+							Name:  "clean-buffers",
 							Image: "centos:centos7",
 							Args:  []string{"sh", "-c", "rm -rf /fluentd-buffers/** || rm /logs/audit/audit.log.pos || rm /logs/kube-apiserver/audit.log.pos || rm /logs/es-containers.log.pos"},
 							SecurityContext: &corev1.SecurityContext{
@@ -535,11 +536,11 @@ func (tc *E2ETestFramework) CleanFluentDBuffers() {
 		clolog.Info("DaemonSet to clean fluent buffers created")
 	}
 	_ = wait.PollImmediate(time.Second*10, time.Minute*5, func() (bool, error) {
-		desired, err2 := oc.Get().Resource("daemonset", "clean-fluentd-buffers").WithNamespace("default").OutputJsonpath("{.status.desiredNumberScheduled}").Run()
+		desired, err2 := oc.Get().Resource("daemonset", "clean-buffers").WithNamespace("default").OutputJsonpath("{.status.desiredNumberScheduled}").Run()
 		if err2 != nil {
 			return false, nil
 		}
-		current, err2 := oc.Get().Resource("daemonset", "clean-fluentd-buffers").WithNamespace("default").OutputJsonpath("{.status.currentNumberScheduled}").Run()
+		current, err2 := oc.Get().Resource("daemonset", "clean-buffers").WithNamespace("default").OutputJsonpath("{.status.currentNumberScheduled}").Run()
 		if err2 != nil {
 			return false, nil
 		}
